@@ -35,8 +35,6 @@ module Network.Wai.Handler.WarpTLS (
     -- * Runner
     , runTLS
     , runTLSSocket
-    , runHTTP2TLS
-    , runHTTP2TLSSocket
     -- * Exception
     , WarpTLSException (..)
     ) where
@@ -48,7 +46,6 @@ import Control.Applicative ((<|>))
 import Control.Exception (Exception, throwIO, bracket, finally, handle, fromException, try, IOException, onException, SomeException(..))
 import qualified Control.Exception as E
 import Control.Monad (void)
-import qualified Crypto.Random.AESCtr
 import qualified Data.ByteString as S
 import qualified Data.ByteString.Lazy as L
 import Data.Default.Class (def)
@@ -60,7 +57,6 @@ import Network.Socket.ByteString (sendAll)
 import qualified Network.TLS as TLS
 import qualified Network.TLS.Extra as TLSExtra
 import Network.Wai (Application)
-import Network.Wai.HTTP2 (HTTP2Application)
 import Network.Wai.Handler.Warp
 import Network.Wai.Handler.Warp.Internal
 import System.IO.Error (isEOFError)
@@ -221,39 +217,20 @@ tlsSettingsChainMemory cert chainCerts key = defaultTlsSettings
 
 ----------------------------------------------------------------
 
--- Composition over two arguments at once; used for runHTTP2\*.
-(.:) :: (c -> d) -> (a -> b -> c) -> a -> b -> d
-f .: g = curry $ f . uncurry g
-
 -- | Running 'Application' with 'TLSSettings' and 'Settings'.
 runTLS :: TLSSettings -> Settings -> Application -> IO ()
-runTLS tset set = runServeTLS tset set . serveDefault
-
--- | Run an HTTP\/2-aware server with 'TLSSettings' and 'Settings'.
-runHTTP2TLS :: TLSSettings -> Settings -> HTTP2Application -> Application -> IO ()
-runHTTP2TLS tset set = runServeTLS tset set .: serveHTTP2
-
-runServeTLS :: TLSSettings -> Settings -> ServeConnection -> IO ()
-runServeTLS tset set serve = withSocketsDo $
+runTLS tset set app = withSocketsDo $
     bracket
         (bindPortTCP (getPort set) (getHost set))
         sClose
-        (\sock -> runServeTLSSocket tset set sock serve)
+        (\sock -> runTLSSocket tset set sock app)
 
 ----------------------------------------------------------------
 
 -- | Running 'Application' with 'TLSSettings' and 'Settings' using
 --   specified 'Socket'.
 runTLSSocket :: TLSSettings -> Settings -> Socket -> Application -> IO ()
-runTLSSocket tset set sock = runServeTLSSocket tset set sock . serveDefault
-
--- | Run an HTTP\/2-aware server with 'TLSSettings' and 'Settings' using
---   specified 'Socket'.
-runHTTP2TLSSocket :: TLSSettings -> Settings -> Socket -> HTTP2Application -> Application -> IO ()
-runHTTP2TLSSocket tset set sock = runServeTLSSocket tset set sock .: serveHTTP2
-
-runServeTLSSocket :: TLSSettings -> Settings -> Socket -> ServeConnection -> IO ()
-runServeTLSSocket tlsset@TLSSettings{..} set sock serve = do
+runTLSSocket tlsset@TLSSettings{..} set sock app = do
     credential <- case (certMemory, keyMemory) of
         (Nothing, Nothing) ->
             either error id <$>
@@ -263,11 +240,11 @@ runServeTLSSocket tlsset@TLSSettings{..} set sock serve = do
             key <- maybe (S.readFile keyFile) return mkey
             either error return $
               TLS.credentialLoadX509ChainFromMemory cert chainCertsMemory key
-    runServeTLSSocket' tlsset set credential sock serve
+    runTLSSocket' tlsset set credential sock app
 
-runServeTLSSocket' :: TLSSettings -> Settings -> TLS.Credential -> Socket -> ServeConnection -> IO ()
-runServeTLSSocket' tlsset@TLSSettings{..} set credential sock serve =
-    runServeSettingsConnectionMakerSecure set get serve
+runTLSSocket' :: TLSSettings -> Settings -> TLS.Credential -> Socket -> Application -> IO ()
+runTLSSocket' tlsset@TLSSettings{..} set credential sock app =
+    runSettingsConnectionMakerSecure set get app
   where
     get = getter tlsset sock params
     params = def { -- TLS.ServerParams
@@ -332,12 +309,7 @@ mkConn tlsset s params = do
 httpOverTls :: TLS.TLSParams params => TLSSettings -> Socket -> S.ByteString -> params -> IO (Connection, Transport)
 httpOverTls TLSSettings{..} s bs0 params = do
     recvN <- makePlainReceiveN s bs0
-#if MIN_VERSION_tls(1,3,0)
     ctx <- TLS.contextNew (backend recvN) params
-#else
-    gen <- Crypto.Random.AESCtr.makeSystem
-    ctx <- TLS.contextNew (backend recvN) params gen
-#endif
     TLS.contextHookSetLogging ctx tlsLogging
     TLS.handshake ctx
     writeBuf <- allocateBuffer bufferSize
